package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.fgw.FgwFj;
import com.ruoyi.system.service.fgw.IFgwFjService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_附件Controller
 * 
 * @author boman
 * @date 2023-03-22
 */
@RestController
@RequestMapping("/fgw/fj")
public class FgwFjController extends BaseController
{
    @Autowired
    private IFgwFjService fgwFjService;

    /**
     * 查询发改委_附件列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwFj fgwFj)
    {
        startPage();
        List<FgwFj> list = fgwFjService.selectFgwFjList(fgwFj);
        return getDataTable(list);
    }

    /**
     * 导出发改委_附件列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:export')")
    @Log(title = "发改委_附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwFj fgwFj)
    {
        List<FgwFj> list = fgwFjService.selectFgwFjList(fgwFj);
        ExcelUtil<FgwFj> util = new ExcelUtil<FgwFj>(FgwFj.class);
        util.exportExcel(response, list, "发改委_附件数据");
    }

    /**
     * 获取发改委_附件详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwFjService.selectFgwFjById(id));
    }

    /**
     * 新增发改委_附件
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:add')")
    @Log(title = "发改委_附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwFj fgwFj)
    {
        return toAjax(fgwFjService.insertFgwFj(fgwFj));
    }

    /**
     * 修改发改委_附件
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:edit')")
    @Log(title = "发改委_附件", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody FgwFj fgwFj)
    {
        return toAjax(fgwFjService.updateFgwFj(fgwFj));
    }

    /**
     * 删除发改委_附件
     */
    @PreAuthorize("@ss.hasPermi('fgw:fj:remove')")
    @Log(title = "发改委_附件", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwFjService.deleteFgwFjByIds(ids));
    }
}
