package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.fgw.FgwJdapFj;
import com.ruoyi.system.service.fgw.IFgwJdapFjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_节点安排_附件Controller
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
@RestController
@RequestMapping("/system/fj")
public class FgwJdapFjController extends BaseController
{
    @Autowired
    private IFgwJdapFjService fgwJdapFjService;

    /**
     * 查询发改委_节点安排_附件列表
     */
    @PreAuthorize("@ss.hasPermi('system:fj:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwJdapFj fgwJdapFj)
    {
        startPage();
        List<FgwJdapFj> list = fgwJdapFjService.selectFgwJdapFjList(fgwJdapFj);
        return getDataTable(list);
    }

    /**
     * 导出发改委_节点安排_附件列表
     */
    @PreAuthorize("@ss.hasPermi('system:fj:export')")
    @Log(title = "发改委_节点安排_附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwJdapFj fgwJdapFj)
    {
        List<FgwJdapFj> list = fgwJdapFjService.selectFgwJdapFjList(fgwJdapFj);
        ExcelUtil<FgwJdapFj> util = new ExcelUtil<FgwJdapFj>(FgwJdapFj.class);
        util.exportExcel(response, list, "发改委_节点安排_附件数据");
    }

    /**
     * 获取发改委_节点安排_附件详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:fj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwJdapFjService.selectFgwJdapFjById(id));
    }

    /**
     * 新增发改委_节点安排_附件
     */
    @PreAuthorize("@ss.hasPermi('system:fj:add')")
    @Log(title = "发改委_节点安排_附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwJdapFj fgwJdapFj)
    {
        return toAjax(fgwJdapFjService.insertFgwJdapFj(fgwJdapFj));
    }

    /**
     * 修改发改委_节点安排_附件
     */
    @PreAuthorize("@ss.hasPermi('system:fj:edit')")
    @Log(title = "发改委_节点安排_附件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FgwJdapFj fgwJdapFj)
    {
        return toAjax(fgwJdapFjService.updateFgwJdapFj(fgwJdapFj));
    }

    /**
     * 删除发改委_节点安排_附件
     */
    @PreAuthorize("@ss.hasPermi('system:fj:remove')")
    @Log(title = "发改委_节点安排_附件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwJdapFjService.deleteFgwJdapFjByIds(ids));
    }
}
