package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.fgw.FgwJzqk;
import com.ruoyi.system.service.fgw.IFgwJzqkService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_进展情况Controller
 * 
 * @author boman
 * @date 2023-03-22
 */
@RestController
@RequestMapping("/fgw/jzqk")
public class FgwJzqkController extends BaseController
{
    @Autowired
    private IFgwJzqkService fgwJzqkService;

    /**
     * 查询发改委_进展情况列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwJzqk fgwJzqk)
    {
        startPage();
        List<FgwJzqk> list = fgwJzqkService.selectFgwJzqkList(fgwJzqk);
        return getDataTable(list);
    }

    /**
     * 导出发改委_进展情况列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:export')")
    @Log(title = "发改委_进展情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwJzqk fgwJzqk)
    {
        List<FgwJzqk> list = fgwJzqkService.selectFgwJzqkList(fgwJzqk);
        ExcelUtil<FgwJzqk> util = new ExcelUtil<FgwJzqk>(FgwJzqk.class);
        util.exportExcel(response, list, "发改委_进展情况数据");
    }

    /**
     * 获取发改委_进展情况详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwJzqkService.selectFgwJzqkById(id));
    }

    /**
     * 新增发改委_进展情况
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:add')")
    @Log(title = "发改委_进展情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwJzqk fgwJzqk)
    {
        return toAjax(fgwJzqkService.insertFgwJzqk(fgwJzqk));
    }

    /**
     * 修改发改委_进展情况
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:edit')")
    @Log(title = "发改委_进展情况", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody FgwJzqk fgwJzqk)
    {
        return toAjax(fgwJzqkService.updateFgwJzqk(fgwJzqk));
    }

    /**
     * 删除发改委_进展情况
     */
    @PreAuthorize("@ss.hasPermi('fgw:jzqk:remove')")
    @Log(title = "发改委_进展情况", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwJzqkService.deleteFgwJzqkByIds(ids));
    }
}
