package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.fgw.FgwShyj;
import com.ruoyi.system.service.fgw.IFgwShyjService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_审核意见Controller
 * 
 * @author boman
 * @date 2023-03-22
 */
@RestController
@RequestMapping("/fgw/shyj")
public class FgwShyjController extends BaseController
{
    @Autowired
    private IFgwShyjService fgwShyjService;

    /**
     * 查询发改委_审核意见列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwShyj fgwShyj)
    {
        startPage();
        List<FgwShyj> list = fgwShyjService.selectFgwShyjList(fgwShyj);
        return getDataTable(list);
    }

    /**
     * 导出发改委_审核意见列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:export')")
    @Log(title = "发改委_审核意见", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwShyj fgwShyj)
    {
        List<FgwShyj> list = fgwShyjService.selectFgwShyjList(fgwShyj);
        ExcelUtil<FgwShyj> util = new ExcelUtil<FgwShyj>(FgwShyj.class);
        util.exportExcel(response, list, "发改委_审核意见数据");
    }

    /**
     * 获取发改委_审核意见详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwShyjService.selectFgwShyjById(id));
    }

    /**
     * 新增发改委_审核意见
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:add')")
    @Log(title = "发改委_审核意见", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwShyj fgwShyj)
    {
        return toAjax(fgwShyjService.insertFgwShyj(fgwShyj));
    }

    /**
     * 修改发改委_审核意见
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:edit')")
    @Log(title = "发改委_审核意见", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody FgwShyj fgwShyj)
    {
        return toAjax(fgwShyjService.updateFgwShyj(fgwShyj));
    }

    /**
     * 删除发改委_审核意见
     */
    @PreAuthorize("@ss.hasPermi('fgw:shyj:remove')")
    @Log(title = "发改委_审核意见", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwShyjService.deleteFgwShyjByIds(ids));
    }
}
