package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.fgw.FgwYjpz;
import com.ruoyi.system.service.fgw.IFgwYjpzService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_预警配置Controller
 * 
 * @author ruoyi
 * @date 2023-03-30
 */
@RestController
@RequestMapping("/fgw/yjpz")
public class FgwYjpzController extends BaseController
{
    @Autowired
    private IFgwYjpzService fgwYjpzService;

    /**
     * 查询发改委_预警配置列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwYjpz fgwYjpz)
    {
        startPage();
        List<FgwYjpz> list = fgwYjpzService.selectFgwYjpzList(fgwYjpz);
        return getDataTable(list);
    }

    /**
     * 导出发改委_预警配置列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:export')")
    @Log(title = "发改委_预警配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwYjpz fgwYjpz)
    {
        List<FgwYjpz> list = fgwYjpzService.selectFgwYjpzList(fgwYjpz);
        ExcelUtil<FgwYjpz> util = new ExcelUtil<FgwYjpz>(FgwYjpz.class);
        util.exportExcel(response, list, "发改委_预警配置数据");
    }

    /**
     * 获取发改委_预警配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwYjpzService.selectFgwYjpzById(id));
    }

    /**
     * 新增发改委_预警配置
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:add')")
    @Log(title = "发改委_预警配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwYjpz fgwYjpz)
    {
        return toAjax(fgwYjpzService.insertFgwYjpz(fgwYjpz));
    }

    /**
     * 修改发改委_预警配置
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:edit')")
    @Log(title = "发改委_预警配置", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody FgwYjpz fgwYjpz)
    {
        return toAjax(fgwYjpzService.updateFgwYjpz(fgwYjpz));
    }

    /**
     * 删除发改委_预警配置
     */
    @PreAuthorize("@ss.hasPermi('fgw:yjpz:remove')")
    @Log(title = "发改委_预警配置", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwYjpzService.deleteFgwYjpzByIds(ids));
    }
}
