package com.ruoyi.web.controller.projectV2;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectV2.ZsyzLcjl;
import com.ruoyi.system.service.projectV2.IZsyzLcjlService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 招商引资_流程记录Controller
 * 
 * @author ruoyi
 * @date 2023-02-27
 */
@RestController
@RequestMapping("/system/lcjl")
public class ZsyzLcjlController extends BaseController
{
    @Autowired
    private IZsyzLcjlService zsyzLcjlService;

    /**
     * 查询招商引资_流程记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZsyzLcjl zsyzLcjl)
    {
        startPage();
        List<ZsyzLcjl> list = zsyzLcjlService.selectZsyzLcjlList(zsyzLcjl);
        return getDataTable(list);
    }

    /**
     * 导出招商引资_流程记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:export')")
    @Log(title = "招商引资_流程记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZsyzLcjl zsyzLcjl)
    {
        List<ZsyzLcjl> list = zsyzLcjlService.selectZsyzLcjlList(zsyzLcjl);
        ExcelUtil<ZsyzLcjl> util = new ExcelUtil<ZsyzLcjl>(ZsyzLcjl.class);
        util.exportExcel(response, list, "招商引资_流程记录数据");
    }

    /**
     * 获取招商引资_流程记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zsyzLcjlService.selectZsyzLcjlById(id));
    }

    /**
     * 新增招商引资_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:add')")
    @Log(title = "招商引资_流程记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZsyzLcjl zsyzLcjl)
    {
        return toAjax(zsyzLcjlService.insertZsyzLcjl(zsyzLcjl));
    }

    /**
     * 修改招商引资_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:edit')")
    @Log(title = "招商引资_流程记录", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody ZsyzLcjl zsyzLcjl)
    {
        return toAjax(zsyzLcjlService.updateZsyzLcjl(zsyzLcjl));
    }

    /**
     * 删除招商引资_流程记录
     */
    @PreAuthorize("@ss.hasPermi('system:lcjl:remove')")
    @Log(title = "招商引资_流程记录", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zsyzLcjlService.deleteZsyzLcjlByIds(ids));
    }
}
