package com.ruoyi.system.service.impl.projectV2;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.constant.CommonConstants;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.projectV2.ZsyzFj;
import com.ruoyi.system.domain.projectV2.ZsyzQktj;
import com.ruoyi.system.mapper.projectV2.ZsyzFjMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.projectV2.ZsyzDjksMapper;
import com.ruoyi.system.domain.projectV2.ZsyzDjks;
import com.ruoyi.system.service.projectV2.IZsyzDjksService;

import static com.ruoyi.common.constant.CommonConstants.LEADER;
import static com.ruoyi.common.constant.CommonConstants.MANAGE;

/**
 * 招商引资_对接客商Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-03-16
 */
@Service
public class ZsyzDjksServiceImpl implements IZsyzDjksService 
{
    @Autowired
    private ZsyzDjksMapper zsyzDjksMapper;
    @Autowired
    private ZsyzFjMapper zsyzFjMapper;

    /**
     * 查询招商引资_对接客商
     * 
     * @param id 招商引资_对接客商主键
     * @return 招商引资_对接客商
     */
    @Override
    public ZsyzDjks selectZsyzDjksById(Long id)
    {
        ZsyzDjks zsyzDjks = zsyzDjksMapper.selectZsyzDjksById(id);
        if(zsyzDjks.getZsyzFjList().size()==1 && StringUtils.isEmpty(zsyzDjks.getZsyzFjList().get(0).getPath())){
            zsyzDjks.setZsyzFjList(new ArrayList<>());
            return zsyzDjks ;
        }
        if(zsyzDjks.getZsyzFjList().size()<=0){
            zsyzDjks.setZsyzFjList(new ArrayList<>());
        }else{
            List<ZsyzFj> zsyzFjList = new ArrayList<>();
            //只拿type为8的附件
            for (ZsyzFj zsyzFj : zsyzDjks.getZsyzFjList()) {
                if(zsyzFj.getType().equals(CommonConstants.EIG)){
                    zsyzFjList.add(zsyzFj);
                }
            }
            zsyzDjks.setZsyzFjList(zsyzFjList);
        }
        return zsyzDjks ;
    }

    /**
     * 查询招商引资_对接客商列表
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 招商引资_对接客商
     */
    @Override
    public List<ZsyzDjks> selectZsyzDjksList(ZsyzDjks zsyzDjks)
    {
        SysUser currentUser = SecurityUtils.getLoginUser().getUser();
        String roleKey = "";
        // 如果是超级管理员/管理员，则不过滤数据
        List<SysRole> roles = SecurityUtils.getLoginUser().getUser().getRoles();
        if (roles != null && roles.size() > 0) {
            roleKey = roles.get(0).getRoleKey();
        }
        if (StringUtils.isNotNull(currentUser) && (currentUser.isAdmin() || MANAGE.equals(roleKey) || LEADER.equals(roleKey))) {
            //如果是admin/或者平台管理员/或者领导 获取到所有数据

        }else{
            zsyzDjks.setDeptId(currentUser.getDeptId());
        }
        return zsyzDjksMapper.selectZsyzDjksList(zsyzDjks);
    }

    /**
     * 新增招商引资_对接客商
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 结果
     */
    @Override
    public int insertZsyzDjks(ZsyzDjks zsyzDjks)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        zsyzDjks.setDeptId(user.getDeptId());
        zsyzDjks.setDeptName(user.getDept().getDeptName());
        zsyzDjks.setCreateTime(DateUtils.getNowDate());
        int count = zsyzDjksMapper.insertZsyzDjks(zsyzDjks);

        //修改附件
        if (zsyzDjks.getZsyzFjList() != null && zsyzDjks.getZsyzFjList().size() > 0) {
            //再将文件新增进数据库
            List<ZsyzFj> zsyzFjList = zsyzDjks.getZsyzFjList();
            if (zsyzFjList != null) {
                for (ZsyzFj zsyzFj : zsyzFjList) {
                    zsyzFj.setSourceId(zsyzDjks.getId());
                    zsyzFj.setType(CommonConstants.EIG);
                    zsyzFj.setXmId(zsyzDjks.getId());
                    //zsyzFj.setXmbh(zsyzSbbzb.getXmbh());
                    zsyzFjMapper.insertZsyzFj(zsyzFj);
                }
            }
        }

        return count;
    }

    /**
     * 修改招商引资_对接客商
     * 
     * @param zsyzDjks 招商引资_对接客商
     * @return 结果
     */
    @Override
    public int updateZsyzDjks(ZsyzDjks zsyzDjks)
    {
        zsyzDjks.setUpdateTime(DateUtils.getNowDate());
        //修改附件
        ZsyzFj zsyzFjDelete = new ZsyzFj();
        zsyzFjDelete.setSourceId(zsyzDjks.getId());
        zsyzFjDelete.setType(CommonConstants.EIG);
        zsyzFjDelete.setXmId(zsyzDjks.getId());
        //先删除相关附件
        zsyzFjMapper.deleteZsyzFjBySourceId(zsyzFjDelete);
        //再将文件新增进数据库
        List<ZsyzFj> zsyzFjList = zsyzDjks.getZsyzFjList();
        if (zsyzFjList != null) {
            for (ZsyzFj zsyzFj : zsyzFjList) {
                zsyzFj.setSourceId(zsyzDjks.getId());
                zsyzFj.setType(CommonConstants.EIG);
                zsyzFj.setXmId(zsyzDjks.getId());
                zsyzFjMapper.insertZsyzFj(zsyzFj);
            }
        }
        return zsyzDjksMapper.updateZsyzDjks(zsyzDjks);
    }

    /**
     * 批量删除招商引资_对接客商
     * 
     * @param ids 需要删除的招商引资_对接客商主键
     * @return 结果
     */
    @Override
    public int deleteZsyzDjksByIds(Long[] ids)
    {
        return zsyzDjksMapper.deleteZsyzDjksByIds(ids);
    }

    /**
     * 删除招商引资_对接客商信息
     * 
     * @param id 招商引资_对接客商主键
     * @return 结果
     */
    @Override
    public int deleteZsyzDjksById(Long id)
    {
        return zsyzDjksMapper.deleteZsyzDjksById(id);
    }
}
